==> libvigraimpex_1.11.1+dfsg.orig.tar.xz: vigra-Version-1-11-1/vigranumpy/src/core/vigranumpycore.cxx <==
/************************************************************************/
/*                                                                      */
/*                 Copyright 2009 by Ullrich Koethe                     */
/*                                                                      */
/*    This file is part of the VIGRA computer vision library.           */
/*    The VIGRA Website is                                              */
/*        http://hci.iwr.uni-heidelberg.de/vigra/                       */
/*    Please direct questions, bug reports, and contributions to        */
/*        ullrich.koethe@iwr.uni-heidelberg.de    or                    */
/*        vigra@informatik.uni-hamburg.de                               */
/*                                                                      */
/*    Permission is hereby granted, free of charge, to any person       */
/*    obtaining a copy of this software and associated documentation    */
/*    files (the "Software"), to deal in the Software without           */
/*    restriction, including without limitation the rights to use,      */
/*    copy, modify, merge, publish, distribute, sublicense, and/or      */
/*    sell copies of the Software, and to permit persons to whom the    */
/*    Software is furnished to do so, subject to the following          */
/*    conditions:                                                       */
/*                                                                      */
/*    The above copyright notice and this permission notice shall be    */
/*    included in all copies or substantial portions of the             */
/*    Software.                                                         */
/*                                                                      */
/*    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND    */
/*    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES   */
/*    OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND          */
/*    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT       */
/*    HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,      */
/*    WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING      */
/*    FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR     */
/*    OTHER DEALINGS IN THE SOFTWARE.                                   */
/*                                                                      */
/************************************************************************/

#define PY_ARRAY_UNIQUE_SYMBOL vigranumpycore_PyArray_API

#include <Python.h>
#include <vigra/config.hxx>
#include <iostream>
#include <boost/python.hpp>
#include <vigra/numpy_array.hxx>
#include <vigra/numpy_array_converters.hxx>
#include <vigra/functorexpression.hxx>
#include <vigra/mathutil.hxx>
#include <vigra/utilities.hxx>
#include <vector>

namespace python = boost::python;

namespace vigra {

UInt32 pychecksum(python::str const & s)
{
#if PY_MAJOR_VERSION < 3
	unsigned int size = len(s);
	return checksum(PyString_AsString(s.ptr()), size);
#elif (PY_MAJOR_VERSION == 3) && (PY_MINOR_VERSION < 3)
	Py_ssize_t size = PyUnicode_GET_DATA_SIZE(s.ptr());
	const char * data = PyUnicode_AS_DATA(s.ptr());
	return checksum(data, size);
#else
	Py_ssize_t size = 0;
	char * data = PyUnicode_AsUTF8AndSize(s.ptr(), &size);
	return checksum(data, size);
#endif
}

void registerNumpyArrayConverters();
void defineAxisTags();
void defineChunkedArray();

} // namespace vigra

using namespace boost::python;
using namespace vigra;

BOOST_PYTHON_MODULE_INIT(vigranumpycore)
{
	if (_import_array() < 0)
		pythonToCppException(0);
	registerNumpyArrayConverters();
    defineAxisTags();
    defineChunkedArray();
    
    def("checksum", &pychecksum, args("data"));
}

==> libvigraimpex_1.12.1+dfsg.orig.tar.xz: vigra-Version-1-12-1/vigranumpy/src/core/vigranumpycore.cxx <==
/************************************************************************/
/*                                                                      */
/*                 Copyright 2009 by Ullrich Koethe                     */
/*                                                                      */
/*    This file is part of the VIGRA computer vision library.           */
/*    The VIGRA Website is                                              */
/*        http://hci.iwr.uni-heidelberg.de/vigra/                       */
/*    Please direct questions, bug reports, and contributions to        */
/*        ullrich.koethe@iwr.uni-heidelberg.de    or                    */
/*        vigra@informatik.uni-hamburg.de                               */
/*                                                                      */
/*    Permission is hereby granted, free of charge, to any person       */
/*    obtaining a copy of this software and associated documentation    */
/*    files (the "Software"), to deal in the Software without           */
/*    restriction, including without limitation the rights to use,      */
/*    copy, modify, merge, publish, distribute, sublicense, and/or      */
/*    sell copies of the Software, and to permit persons to whom the    */
/*    Software is furnished to do so, subject to the following          */
/*    conditions:                                                       */
/*                                                                      */
/*    The above copyright notice and this permission notice shall be    */
/*    included in all copies or substantial portions of the             */
/*    Software.                                                         */
/*                                                                      */
/*    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND    */
/*    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES   */
/*    OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND          */
/*    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT       */
/*    HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,      */
/*    WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING      */
/*    FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR     */
/*    OTHER DEALINGS IN THE SOFTWARE.                                   */
/*                                                                      */
/************************************************************************/

#define PY_ARRAY_UNIQUE_SYMBOL vigranumpycore_PyArray_API

#include <Python.h>
#include <vigra/config.hxx>
#include <iostream>
#include <boost/python.hpp>
#include <vigra/numpy_array.hxx>
#include <vigra/numpy_array_converters.hxx>
#include <vigra/functorexpression.hxx>
#include <vigra/mathutil.hxx>
#include <vigra/utilities.hxx>
#include <vector>

namespace python = boost::python;

namespace vigra {

UInt32 pychecksum(python::str const & s)
{
#if PY_MAJOR_VERSION < 3
	unsigned int size = len(s);
	return checksum(PyString_AsString(s.ptr()), size);
#elif (PY_MAJOR_VERSION == 3) && (PY_MINOR_VERSION < 3)
	Py_ssize_t size = PyUnicode_GET_DATA_SIZE(s.ptr());
	const char * data = PyUnicode_AS_DATA(s.ptr());
	return checksum(data, size);
#else
	Py_ssize_t size = 0;
	const char * data = PyUnicode_AsUTF8AndSize(s.ptr(), &size);
	return checksum(data, size);
#endif
}

void registerNumpyArrayConverters();
void defineAxisTags();
void defineChunkedArray();

} // namespace vigra

using namespace boost::python;
using namespace vigra;

BOOST_PYTHON_MODULE_INIT(vigranumpycore)
{
	if (_import_array() < 0)
		pythonToCppException(0);
	registerNumpyArrayConverters();
    defineAxisTags();
    defineChunkedArray();
    
    def("checksum", &pychecksum, args("data"));
}
